@@ -75,13 +75,26 @@ parser.add_argument(
     nargs="+",
     help="add exclude item for parts of the configuration which will "
          "be omitted from the comparison (these will be added to those "
-         "read from a file with the -y option, if both are used)")
+         "read from a file with the -y option, if both are used), "
+         "specified as a dictionary path, with keys separated by "
+         "colons")
 
 parser.add_argument(
     "-y", "--exclude-filename",
     metavar="FILENAME",
-    dest="exclude_filename",
-    help="read exclude items from file")
+    help="read exclude items from lines in file")
+
+parser.add_argument(
+    "-z", "--exclude-yaml-filename",
+    metavar="FILENAME",
+    help="read exclude items from a YAML file")
+
+parser.add_argument(
+    "-Z", "--exclude-yaml-path",
+    default="",
+    help="path into file specified with -z to where exclude items are "
+         "held, specified as a dictionary path, with keys separated by "
+         "colons")
 
 parser.add_argument(
     "-e", "--explain",
@@ -97,7 +110,8 @@ parser.add_argument(
 parser.add_argument(
     "-O", "--no-output",
     action="store_true",
-    help="")
+    help="do not write changes output file - used to test parsing, "
+         "exclude and conversion process")
 
 parser.add_argument(
     "-X", "--debug-excludes",
@@ -178,6 +192,8 @@ config_parser_class, config_diff_class = PLATFORMS[args.platform]
 
 exclude_items = args.exclude_items
 exclude_filename = args.exclude_filename
+exclude_yaml_filename = args.exclude_yaml_filename
+exclude_yaml_path = args.exclude_yaml_path
 explain = args.explain
 quiet = args.quiet
 no_output = args.no_output
@@ -245,21 +261,44 @@ elif len(devicenames) > 1:
 
 
 
-# create the diff object
+# create the diff object once at the start
 
 diff = config_diff_class(explain, debug_config, debug_diff, debug_convert)
 
 
-# read the excludes for what to include/exclude in the comparison
+# add any excludes specified on the command line
 
 if exclude_items:
     # add the exclude items specified directly on the command line (do
     # this before reading those from a file, if specified, below)
+
     diff.add_excludes(exclude_items)
 
+
+# if an exclude [simple] file was specified, read and add those
+
 if exclude_filename:
     diff.read_excludes(exclude_filename)
 
+
+# if an exclude YAML file was specified, read that in
+
+if exclude_yaml_filename:
+    try:
+        diff.read_excludes_yaml(exclude_yaml_filename, exclude_yaml_path)
+
+    except TypeError:
+        print("error: exclude YAML path references non-dictionary item "
+              "in file", file=sys.stderr)
+
+        exit(1)
+
+    except KeyError:
+        print("error: exclude YAML path not found in file", file=sys.stderr)
+
+        exit(1)
+
+
 if debug_excludes:
     print(">> exclude items:", yaml.dump(diff.get_excludes(),
           default_flow_style=False), sep="\n", file=sys.stderr)
