@@ -682,6 +682,14 @@ class CiscoIOSDiffConfig(DiffConfig):
         return "! => " + pathstr(path)
 
 
+    def _changes_end(self):
+        """This method overrides the empty inherited one to return a
+        single line saying 'end'.
+        """
+
+        return ["end"]
+
+
     def init_excludes(self):
         """This method extends the inherited one to add some default
         excludes for the default CoPP (Control Plane Policing) IPv4
